@@ -4,14 +4,27 @@ quicklook
 A simple way to visualize numpy arrays
 """
 
+# standard library
+import os
+import sys
+from pathlib import Path
+from numbers import Number
+
+# 3rd party distribution packages
 import numpy as np
 from numpy import min, max
 import matplotlib.pyplot as plt
 from matplotlib import image
-from numbers import Number
 import typer
-import os
-from pathlib import Path
+
+# local modules
+here = os.path.dirname(os.path.realpath(__file__))
+sys.path.append(here)
+from example_arrays import static
+
+#
+#
+#
 
 
 def replace_nan(arr):
@@ -53,14 +66,15 @@ def bytescale(arr):
     to be between 0 and 255 and have 8bits (i.e .a byte) of depth per channel.
     """
 
+    # all zeros
+    if not np.any(arr):
+        return arr
+
     # float dtype (temporarily) during scaling
     arr = arr.astype(float)
 
     # linear scale between 0 and 255
-    if min(arr) == max(arr):
-        arr = 255 * arr / np.max(arr)
-    else:
-        arr = 255 * ((arr - np.min(arr)) / (np.max(arr) - np.min(arr)))
+    arr = 255 * ((arr - np.min(arr)) / (np.max(arr) - np.min(arr)))
 
     # byte data type
     arr = np.uint8(arr)
@@ -103,21 +117,6 @@ def reshape_array(arr):
     return arr
 
 
-def static(width: int = 100, height: int = 100):
-    """
-    a random 2D array
-
-    This function is called "static" because the output looks like
-    the white noise signal that televisions show(ed) when
-    there is no incoming broadcast signal
-    """
-
-    if not (isinstance(width, int) and isinstance(height, int)):
-        raise TypeError("width and heigh must be integers")
-
-    return np.random.rand(height, width)
-
-
 def matplotlib_display(arr, figsize, title, cmap):
     """display array in a window using matplotlib"""
 
@@ -128,7 +127,7 @@ def matplotlib_display(arr, figsize, title, cmap):
 
 
 def show(arr: np.ndarray, clip=0, title="", cmap="viridis", figsize=(5, 5)):
-    """quick and easy way to visualize a numpy array"""
+    """show numpy array"""
 
     if not isinstance(arr, (np.ndarray)):
         raise TypeError(f"Input must be a numpy array was given a {type(arr)}")
@@ -150,7 +149,7 @@ def load(fpath: str) -> np.ndarray:
     return image.imread(fpath)
 
 
-def cli(filepath: str, title: str = "", clip: int = 0, cmap: str = "viridis"):
+def cli(filepath: str = "", title: str = "", clip: int = 0, cmap: str = "viridis"):
     """
     Quicklook command line interface
 
@@ -164,21 +163,26 @@ def cli(filepath: str, title: str = "", clip: int = 0, cmap: str = "viridis"):
 
     """
 
-    # Primary purpose of this try block is to return a nice clean error message
-    # if the user gives an incorrect file path (somewhat likely eventually?)
-    try:
-        arr = load(filepath)
-    except:
-        print(f"Unable to load: {filepath}")
-        return
+    if not filepath:
+        print(
+            """
+      No filepath given, to load file from path:
 
-    if not title:
-        title = Path(filepath).stem
+      quicklook --filepath = path/to/file.png"""
+        )
+        arr = static()
+    else:
+        arr = load(filepath)
+        if not title:
+            title = Path(filepath).stem
 
     show(arr, clip=clip, title=title, cmap=cmap)
 
 
-if __name__ == "__main__":
-
-    # pretty command line interface using typer
+def main():
+    """pretty command line interface using typer"""
     typer.run(cli)
+
+
+if __name__ == "__main__":
+    main()
